@@ -1,7 +1,7 @@
 #ifndef R_VERSION_H
 #define R_VERSION_H 1
 #define R2_VERSION_COMMIT 0
-#define R2_GITTAP "1.2.1"
+#define R2_GITTAP "1.3.0"
 #define R2_GITTIP "HEAD"
-#define R2_BIRTH "2017-02-03"
+#define R2_BIRTH "2017-03-14__06:54:54"
 #endif
